/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.Iterator;
import java.util.List;

// Generated classes
import samples.j2ee.web_app_2_2.*;
import samples.j2ee.enhydra_service_1_0.*;
import samples.j2ee.ejb_jar_2_0.*;

public class TestJ2EEDTDs {

    public static void main(String[] args) {
        if (args.length != 3) {
            System.out.println("Usage: java TestJ2EEDTDs " +
                "<web.xml location> <enhydra-service.xml location> " +
                "<ejb-jar.xml location>");
            return;
        }

        try {
            WebAppUnmarshaller.setErrorHandler(new CommandLineErrorHandler());
            WebApp webApp =
                WebAppUnmarshaller.unmarshal(new File(args[0]), false);
            System.out.println("\n\nProcessed Web XML...");

            // Set a DTD
            webApp.setDocType(null, null, null);
            //webApp.setDocType("web-app", "", "DTD/web-app.dtd");

            // Set encoding
            webApp.setOutputEncoding("ISO-8859-1");

            // New way of marshalling
            webApp.marshal(new File("outputWeb.xml"));
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }

        try {
            EnhydraServiceUnmarshaller.setErrorHandler(
                new CommandLineErrorHandler());
            EnhydraService enhydraService =
                EnhydraServiceUnmarshaller.unmarshal(new File(args[1]));
            System.out.println("\n\nProcessed Enhydra Service XML...");


            List services = enhydraService.getServiceList();

            for (Iterator i = services.iterator(); i.hasNext(); ) {
                Service service = (Service)i.next();
                System.out.print("  Found service");
                if (service.getDisplayName() != null) {
                    System.out.print(" named " +
                        service.getDisplayName().getValue());
                }
                System.out.println();

                ServiceDesc serviceDesc = service.getServiceDesc();
                if (serviceDesc != null) {
                    System.out.println("  + Service Name: " +
                        serviceDesc.getServiceName().getValue());
                    System.out.println("  + Service Class Name: " +
                        serviceDesc.getServiceClassName().getValue());
                    System.out.println("  + M-Bean Name: " +
                        serviceDesc.getMbeanName());

                    List exportJars = serviceDesc.getExportJarList();
                    for (Iterator j = exportJars.iterator(); j.hasNext(); ) {
                        ExportJar exportJar = (ExportJar)j.next();
                        System.out.println("    + Exported Jar: " +
                            exportJar.getValue());
                    }
                }
            }

            // New way of marshalling
            enhydraService.marshal(new File("outputEnhydraService.xml"));
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }

        try {
            EjbJarUnmarshaller.setErrorHandler(new CommandLineErrorHandler());
            EjbJar ejbJar =
                EjbJarUnmarshaller.unmarshal(new File(args[2]));
            System.out.println("\n\nProcessed EJB Jar XML...");

            // New way of marshalling
            ejbJar.marshal(new File("outputEJBJar.xml"));
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }
    }
}


